@@ -21,7 +21,6 @@ import shutil
 from .spec import Spec
 from .template import Tpl
 from .generator import *
-from .validator import validate
 
 
 def check_output(output):
@@ -37,13 +36,14 @@ def check_output(output):
 def write_files(output, files):
     def gen_output(d):
         return os.path.join(output, d)
-    
+
     for name, content in files:
         if content == "":
             continue
         with open(gen_output(name), "w") as f:
             f.write(content)
 
+
 def check_version(j, logger):
     version = j.get("version")
 
@@ -58,7 +58,7 @@ def check_version(j, logger):
     logger.info("Correct file version ✅")
 
 
-def c_gen(templates, output, json_file, skel, logger):
+def c_gen(spec, templates, output, skel, logger):
     # copy skel directory
     status, err = check_output(output)
     if not status:
@@ -77,24 +77,6 @@ def c_gen(templates, output, json_file, skel, logger):
 
     tpl.open_tpl_files()
 
-    with open(json_file) as f:
-        r = f.read()
-
-    logger.info("JSON spec file successfully read ✅")
-
-    j = json.loads(r)
-    spec = Spec()
-    spec.decompile(j)
-    failed = validate(logger, spec)
-    if len(failed) > 0:
-        return
-    logger.info("Validated JSON ✅")
-
-    check_version(j, logger)
-
-    logger.info("JSON loaded into Spec ✅")
-    
-
     files = []
 
     can_ids = build_can_ids(spec, tpl)
